import requests
from termcolor import colored
def enum(domain, filename):
    try:
        r=requests.get(f"https://otx.alienvault.com/api/v1/indicators/domain/{domain}/passive_dns")
        data=r.json()["passive_dns"]
        with open(filename, "a") as file:
            for i in range(0, len(data)):
                try:
                    file.writelines("%s\n" % data[i]["hostname"])
                    print(colored("[Alien Vault]"+" "+data[i]["hostname"], "blue"))
                except Exception as e:
                    pass
    except Exception as e:
        print("Cannot run source alien vault")


import requests
from termcolor import colored


def enum(domain, api, filename):
    try:
        headers={'Accept' : 'application/json'}
        r=requests.get(f"https://recon.dev/api/search?key={api}&domain={domain}", headers=headers)
        data=r.json()
        with open(filename, "a") as file:
            for i in range(0, len(data)):
                try:
                    for j in range(0, len(data[i]["rawDomains"])):
                        file.writelines("%s\n" % data[i]["rawDomains"][j])
                        print(colored("[Recon Dev]"+" "+data[i]["rawDomains"][j], "blue"))
                except Exception as e:
                    pass
    except Exception as e:
        print("Cannot run source recondev")


import requests
from termcolor import colored


def enum(domain, api, filename):
    try:
        url = f"https://api.securitytrails.com/v1/domain/{domain}/subdomains"
        querystring = {"children_only":"false"}
        headers = {"Accept": "application/json","APIKEY": f"{api}"}
        r = requests.get(url, headers=headers, params=querystring)
        data = r.json()["subdomains"]
        with open(filename, "a") as file:
            for i in range(0, len(data)):
                try:
                    file.writelines("%s\n" % data[i])
                    print(colored("[Security Trails]"+" "+data[i]+"."+f"{domain}", "blue"))
                except Exception as e:
                    pass
    except Exception as e:
        print("Cannot run source security trails")


import requests
from termcolor import colored

def enum(domain, api, filename):
    try:
        headers={'X-Key': f"{api}"}
        r=requests.get(f"https://api.binaryedge.io/v2/query/domains/subdomain/{domain}", headers=headers)
        data=r.json()["events"]
        with open(filename, "a") as file:
            for i in range(0, len(data)):
                try:
                    file.writelines("%s\n" % data[i])
                    print(colored("[Binary edge]"+" "+data[i]+" ", "blue"))
                except Exception as e:
                    pass
    except Exception as e:
        print("Cannot run source binary edge")


import requests
from termcolor import colored

def enum(domain, api, filename):
    try:
        headers={"Authorization" : f"{api}"}
        r=requests.get(f"https://dns.projectdiscovery.io/dns/{domain}/subdomains", headers=headers)
        data=r.json()["subdomains"]
        with open(filename, "a") as file:
            for i in range(0, len(data)):
                try:
                    file.writelines("%s%s%s\n" % (data[i], ".", f"{domain}"))
                    print(colored("[Chaos]"+" "+data[i]+"."+f"{domain}", "blue"))
                except Exception as e:
                    pass
    except Exception as e:
        print("Cannot run source chaos")



import requests
from termcolor import colored


def enum(domain, api, filename):
    try:
        url = 'https://www.virustotal.com/vtapi/v2/domain/report'
        params = {'apikey':f'{api}', 'domain': f'{domain}'}
        r = requests.get(url, params=params)
        data=r.json()["subdomains"]
        with open(filename, "a") as file:
            for i in range(0, len(data)):
                try:
                    file.writelines("%s\n" % data[i])
                    print(colored("[Virus Total]"+" "+data[i], "blue"))
                except Exception as e:
                    pass
    except Exception as e:
        print("Cannot run source virus total")


import requests
from termcolor import colored, cprint
def enum(domain, filename):
    try:
        r=requests.get(f"https://jldc.me/anubis/subdomains/{domain}")
        data=r.json()
        with open(filename, "a") as file:
            for i in range(0, len(data)):
                try:
                    file.writelines("%s\n" % data[i])
                    print(colored("[Anubis]"+" "+data[i], "blue"))
                except Exception as e:
                    pass
    except Exception as e:
        print("Cannot run source anubis")


import requests
from termcolor import colored, cprint

def enum(domain, api, filename):
    try:
        url = "https://api.spyse.com/v3/data/domain/subdomain"
        querystring = {"domain":f"{domain}","limit":"100"}
        headers = {"Accept": "application/json", "Authorization": "Bearer %s" % api}
        r = requests.request("GET", url, headers=headers, params=querystring)
        data=r.json()["data"]["items"]
        with open(filename, "a") as file:
            for i in range(0, len(data)):
                try:
                    file.writelines("%s\n" % data[i]["name"])
                    print(colored("[Spyse]"+" "+data[i]['name'], "blue"))
                except Exception as e:
                    pass
    except Exception as e:
        print("Cannot run source spyse")


import requests
from termcolor import colored, cprint
def enum(domain, api, filename):
    try:
        headers={'Authorization': 'Bearer %s' % api }
        r=requests.get(f"https://api.certspotter.com/v1/issuances?domain={domain}&include_subdomains=true&expand=dns_names", headers=headers)
        data=r.json()
        with open(filename, "a") as file:
            for i in range(0, len(data)):
                try:
                    for j in range(0, len(data[i]["dns_names"])):
                        try:
                            file.writelines("%s\n" % data[i]["dns_names"][j])
                            print(colored("[Certspotter]"+" "+data[i]["dns_names"][j], "blue"))
                        except Exception as e:
                            pass
                except Exception as e:
                    pass
    except Exception as e:
        print("Cannot run source certspotter")



from setuptools import setup, find_packages
import codecs
import os

here = os.path.abspath(os.path.dirname(__file__))

with codecs.open(os.path.join(here, "README.md"), encoding="utf-8") as fh:
    long_description = "\n" + fh.read()

VERSION = '0.0.1'
DESCRIPTION = "Sikert let's you do subdomain enumeration"
LONG_DESCRIPTION = 'A package that allows to enumerate subdomain from different sources'

# Setting up
setup(
    name="sikert",
    version=VERSION,
    author="Deepanjal kumar (Operation Falcon)",
    author_email="operationfalcon6@gmail.com",
    description=DESCRIPTION,
    long_description_content_type="text/markdown",
    long_description=long_description,
    packages=find_packages(),
    install_requires=['certifi==2020.12.5', 'chardet==4.0.0', 'idna==2.10', 'requests==2.25.1', 'termcolor==1.1.0', 'urllib3==1.26.4'],
    keywords=['python', 'sikert', 'subdomain enumeration', 'sources'],
    classifiers=[
        "Development Status :: 1 - Planning",
        "Intended Audience :: Developers",
        "Programming Language :: Python :: 3",
        "Operating System :: Unix"
    ]
)